==> icradius-0.6.tar.gz: icradius-0.6/scripts/radiusfixup.pl <==
#!/usr/bin/perl


use DBI;
use strict;

my $dbusername = 'root';
my $dbpassword = 'rootpass';

my $dbh = DBI->connect("DBI:mysql:radius",$dbusername, $dbpassword);

my $sth;
my $sth1;

$sth = $dbh->prepare("SELECT DISTINCT UserName FROM radreply");
$sth->execute;

my $i = 0;
my $j = 0;
while (my $user = $sth->fetchrow_array) {
  $i++;

  my $seenipaddress = 0;
  my $seenservicetype = 0;
  my $seenprotocol = 0;
  my $seensessto = 0;
  my $seenidleto = 0;
  my $seencomp = 0;

 $sth1 = $dbh->prepare("SELECT id FROM radreply WHERE Attribute = \"Framed-IP-Address\" AND Value=\"255.255.255.254\" AND UserName = \"$user\"");
 $sth1->execute;
 $seenipaddress = $sth1->fetchrow_array;

 $sth1 = $dbh->prepare("SELECT id FROM radreply WHERE Attribute = \"Service-Type\" AND Value=\"Framed-User\" AND UserName = \"$user\"");
 $sth1->execute;
 $seenservicetype = $sth1->fetchrow_array;

 $sth1 = $dbh->prepare("SELECT id FROM radreply WHERE Attribute = \"Framed-Protocol\" AND Value=\"PPP\" AND UserName = \"$user\"");
 $sth1->execute;
 $seenprotocol = $sth1->fetchrow_array;

 $sth1 = $dbh->prepare("SELECT id FROM radreply WHERE Attribute = \"Session-Timeout\" AND Value=\"21600\" AND UserName = \"$user\"");
 $sth1->execute;
 $seensessto = $sth1->fetchrow_array;

 $sth1 = $dbh->prepare("SELECT id FROM radreply WHERE Attribute = \"Idle-Timeout\" AND Value=\"1800\" AND UserName = \"$user\"");
 $sth1->execute;
 $seenidleto = $sth1->fetchrow_array;

 $sth1 = $dbh->prepare("SELECT id FROM radreply WHERE Attribute = \"Framed-Compression\" AND Value=\"Van-Jacobson-TCP-IP\" AND UserName = \"$user\"");
 $sth1->execute;
 $seencomp = $sth1->fetchrow_array;
 
 if ($seenipaddress && $seenservicetype && $seensessto && $seenidleto && $seencomp && $seenprotocol) {
   my @ids = ($seenipaddress, $seenservicetype, $seensessto, $seenidleto, $seencomp, $seenprotocol);
   my $sth2;
   foreach my $id (@ids) {
      $sth2 = $dbh->do("DELETE FROM radreply WHERE id = \"$id\"");
   }
   $sth2 = $dbh->do("INSERT INTO usergroup VALUES \(\"\",\"$user\",\"PPP\"\)");
   $j++;
 }

}
$sth1->finish;
$sth->finish;

 print "Found $j users of $i that should be in group PPP\n";


$sth = $dbh->prepare("SELECT UserName, Value FROM radreply WHERE Attribute = \"Port-Limit\"");
$sth->execute;
$i = 0;
while (my @rows = $sth->fetchrow_array) {
  $i++;
  $sth1 = $dbh->do("INSERT INTO usergroup VALUES \(\"\",\"$rows[0]\",\"Limit$rows[1]\"\)");
  $sth1 = $dbh->do("DELETE FROM radreply WHERE UserName = \"$rows[0]\" AND Attribute = \"Port-Limit\"");
  

}
$sth->finish;

  print "Found $i users with a port limit and set their Simultaneous-Use\n";
  

$sth = $dbh->prepare("SELECT UserName, Value FROM radcheck WHERE Attribute = \"NAS-Port-Type\"");
$sth->execute;
$i = 0;
while (my @rows = $sth->fetchrow_array) {
  $i++;
  $sth1 = $dbh->do("INSERT INTO usergroup VALUES \(\"\",\"$rows[0]\",\"$rows[1]\"\)");
  $sth1 = $dbh->do("DELETE FROM radcheck WHERE UserName = \"$rows[0]\" AND Attribute = \"NAS-Port-Type\"");

}
$sth->finish;
  print "Found $i users with a NAS-Port-Type and inserted them in the correct group\n";


$dbh->disconnect;

==> icradius-0.17b.tar.gz: icradius-0.17b/scripts/radiusfixup.pl <==
#!/usr/bin/perl


use DBI;
use strict;

my $dbusername = 'root';
my $dbpassword = 'rootpass';

my $dbh = DBI->connect("DBI:mysql:radius",$dbusername, $dbpassword);

my $sth;
my $sth1;

$sth = $dbh->prepare("SELECT DISTINCT UserName FROM radreply");
$sth->execute;

my $i = 0;
my $j = 0;
while (my ($user) = $sth->fetchrow_array) {
  $i++;

  my $seenipaddress = 0;
  my $seenservicetype = 0;
  my $seenprotocol = 0;
  my $seensessto = 0;
  my $seenidleto = 0;
  my $seencomp = 0;

 $sth1 = $dbh->prepare("SELECT id FROM radreply WHERE Attribute = \"Framed-IP-Address\" AND Value=\"255.255.255.254\" AND UserName = \"$user\"");
 $sth1->execute;
 $seenipaddress = $sth1->fetchrow_array;

 $sth1 = $dbh->prepare("SELECT id FROM radreply WHERE Attribute = \"Service-Type\" AND Value=\"Framed-User\" AND UserName = \"$user\"");
 $sth1->execute;
 $seenservicetype = $sth1->fetchrow_array;

 $sth1 = $dbh->prepare("SELECT id FROM radreply WHERE Attribute = \"Framed-Protocol\" AND Value=\"PPP\" AND UserName = \"$user\"");
 $sth1->execute;
 $seenprotocol = $sth1->fetchrow_array;

 $sth1 = $dbh->prepare("SELECT id FROM radreply WHERE Attribute = \"Session-Timeout\" AND Value=\"21600\" AND UserName = \"$user\"");
 $sth1->execute;
 $seensessto = $sth1->fetchrow_array;

 $sth1 = $dbh->prepare("SELECT id FROM radreply WHERE Attribute = \"Idle-Timeout\" AND Value=\"1800\" AND UserName = \"$user\"");
 $sth1->execute;
 $seenidleto = $sth1->fetchrow_array;

 $sth1 = $dbh->prepare("SELECT id FROM radreply WHERE Attribute = \"Framed-Compression\" AND Value=\"Van-Jacobson-TCP-IP\" AND UserName = \"$user\"");
 $sth1->execute;
 $seencomp = $sth1->fetchrow_array;
 
 if ($seenipaddress && $seenservicetype && $seensessto && $seenidleto && $seencomp && $seenprotocol) {
   my @ids = ($seenipaddress, $seenservicetype, $seensessto, $seenidleto, $seencomp, $seenprotocol);
   my $sth2;
   foreach my $id (@ids) {
      $sth2 = $dbh->do("DELETE FROM radreply WHERE id = \"$id\"");
   }
   $sth2 = $dbh->do("INSERT INTO usergroup VALUES \(\"\",\"$user\",\"PPP\"\)");
   $j++;
 }

}
$sth1->finish;
$sth->finish;

 print "Found $j users of $i that should be in group PPP\n";


$sth = $dbh->prepare("SELECT UserName, Value FROM radreply WHERE Attribute = \"Port-Limit\"");
$sth->execute;
$i = 0;
while (my @rows = $sth->fetchrow_array) {
  $i++;
  $sth1 = $dbh->do("INSERT INTO usergroup VALUES \(\"\",\"$rows[0]\",\"Limit$rows[1]\"\)");
  $sth1 = $dbh->do("DELETE FROM radreply WHERE UserName = \"$rows[0]\" AND Attribute = \"Port-Limit\"");
  

}
$sth->finish;

  print "Found $i users with a port limit and set their Simultaneous-Use\n";
  

$sth = $dbh->prepare("SELECT UserName, Value FROM radcheck WHERE Attribute = \"NAS-Port-Type\"");
$sth->execute;
$i = 0;
while (my @rows = $sth->fetchrow_array) {
  $i++;
  $sth1 = $dbh->do("INSERT INTO usergroup VALUES \(\"\",\"$rows[0]\",\"$rows[1]\"\)");
  $sth1 = $dbh->do("DELETE FROM radcheck WHERE UserName = \"$rows[0]\" AND Attribute = \"NAS-Port-Type\"");

}
$sth->finish;
  print "Found $i users with a NAS-Port-Type and inserted them in the correct group\n";


$dbh->disconnect;
